==> gcomp_2.0.5a.beta.zip: Declarations.h <==

#ifndef DECLARATIONS_H
#define DECLARATIONS_H

#include <afx.h>
#include <afxtempl.h>
#include <ole2.h>   //IStream, IStorage
#include <io.h> //_findfirst(), _findnext()
#include <stdlib.h>
#include <stdio.h>

#define BUFFER_SIZE 256 //buffer for I/O operations


class CTaskParameters;
class CNameTable;
class CNameTableRecord;

class CStorage; //Compound storages
class CContainer;
class CStreamInfo;


class CMMSObject; //generic MMS object
typedef CMMSObject* PCMMSObject;
typedef CMMSObject& RCMMSObject;
class CMMS;

class CMMSNodeList; //Untyped objects list

//Types of Main Metadata Stream parts and name table objects
typedef enum {
	MMS_Property,
	MMS_Object, //untyped object
	MMS_MainDataContDef,
	MMS_TaskItem,
	MMS_GenJrnlFldDef,
	MMS_DocSelRefObj,
	MMS_DocNumDef,
	MMS_Consts,
	MMS_SbCnts,
	MMS_SbCnt,
	MMS_Registers,
	MMS_Documents,
	MMS_Document,
	MMS_DocRefers, //  
	MMS_DocHeadFields,
	MMS_DocTableFields,
	MMS_Journalister,
	MMS_Journalisters,
	MMS_EnumList,
	MMS_Report,
	MMS_ReportList,
	MMS_CalcJournal,
	MMS_CalcJournals,
	MMS_Calendars,
	MMS_CalcAlgorithm,
	MMS_CalcAlgorithms,
	MMS_RecalcRules,
	MMS_CalcVars,
	MMS_Groups,
	MMS_DocumentStreams,
	MMS_DocumentStream,
	MMS_Buh,
	//        
	NT_MainMetadataStream,
	NT_MetadataPart,
	NT_Workbook,
	NT_FormModule,
	NT_DialogForm,
	NT_ListForm,
	NT_MoxelSheet,
	NT_TransModuleStor,
	NT_TransactModule,
	NT_GlobalModuleStor,
	NT_GlobalModule,
	NT_UserHelpStor,
	NT_UserHelp,
	NT_ErtUserHelp,
	NT_SubcontoFolder,
	NT_SubcontoListForm,
	NT_CalcAlgorithm,
	NT_AccFormStor,
	NT_AccForm,
	NT_OperFormStor,
	NT_OperForm,
	NT_AccListForm,
	NT_OperListForm,
	NT_ProvListForm,
	NT_GlobalData,
	NT_CommonMXL,
	NT_PictureGallery,
	NT_GUIDData,
	NT_TagStream,
	NT_UserInterface,
	NT_UserRights,
	NT_ObjectOrdering
} MMSObjectType;


//Global variables
extern CTaskParameters TaskParameters;
extern CNameTable NameTable;


#endif

==> gcomp_2.0.7.beta.zip: Declarations.h <==

#ifndef DECLARATIONS_H
#define DECLARATIONS_H

#include <afx.h>
#include <afxtempl.h>
#include <ole2.h>   //IStream, IStorage
#include <io.h> //_findfirst(), _findnext()
#include <stdlib.h>
#include <stdio.h>

#define BUFFER_SIZE 256 //buffer for I/O operations


class CTaskParameters;
class CNameTable;
class CNameTableRecord;

class CStorage; //Compound storages
class CContainer;
class CStreamInfo;

class CObjectOrdering;


class CMMSObject; //generic MMS object
typedef CMMSObject* PCMMSObject;
typedef CMMSObject& RCMMSObject;
class CMMS;

class CMMSBuh;
class CMMSAccountPlan;
class CMMSAccount;

class CMMSNodeList; //Untyped objects list

//Types of Main Metadata Stream parts and name table objects
typedef enum {
	MMS_Property,
	MMS_Object, //untyped object
	MMS_MainDataContDef,
	MMS_TaskItem,
	MMS_GenJrnlFldDef,
	MMS_DocSelRefObj,
	MMS_DocNumDef,
	MMS_Consts,
	MMS_SbCnts,
	MMS_SbCnt,
	MMS_Registers,
	MMS_Documents,
	MMS_Document,
	MMS_DocRefers, //  
	MMS_DocHeadFields,
	MMS_DocTableFields,
	MMS_Journalister,
	MMS_Journalisters,
	MMS_EnumList,
	MMS_Report,
	MMS_ReportList,
	MMS_CalcJournal,
	MMS_CalcJournals,
	MMS_Calendars,
	MMS_CalcAlgorithm,
	MMS_CalcAlgorithms,
	MMS_RecalcRules,
	MMS_CalcVars,
	MMS_Groups,
	MMS_DocumentStreams,
	MMS_DocumentStream,
	MMS_Buh,
	MMS_AccParams,
	MMS_Plans,
	MMS_Plan,
	MMS_Account,
	MMS_ProvParams,
	MMS_OperParams,
	MMS_SbKind,
	MMS_TypOpersDef,
	MMS_CorrProvsDef,
	MMS_ProvHardFldDef,
	MMS_OperJournal,
	//        
	NT_MainMetadataStream,
	NT_MetadataPart,
	NT_Workbook,
	NT_FormModule,
	NT_DialogForm,
	NT_ListForm,
	NT_MoxelSheet,
	NT_TransModuleStor,
	NT_TransactModule,
	NT_GlobalModuleStor,
	NT_GlobalModule,
	NT_UserHelpStor,
	NT_UserHelp,
	NT_ErtUserHelp,
	NT_SubcontoFolder,
	NT_SubcontoListForm,
	NT_CalcAlgorithm,
	NT_AccFormStor,
	NT_AccForm,
	NT_OperFormStor,
	NT_OperForm,
	NT_AccListForm,
	NT_OperListForm,
	NT_ProvListForm,
	NT_UnknownListForm,
	NT_GlobalData,
	NT_CommonMXL,
	NT_PictureGallery,
	NT_GUIDData,
	NT_TagStream,
	NT_UserInterface,
	NT_UserRights,
	NT_ObjectOrdering
} MMSObjectType;


//Global variables
extern CTaskParameters TaskParameters;
extern CNameTable NameTable;


#endif
